import ActionConstants from '../constants/ActionConstants.js';
import {createAction} from 'redux-actions';
import moment from 'moment';
import uuid from 'node-uuid';
import TodoClient from '../client/TodoClient.js';

const todoClient = new TodoClient();

function newEntry(text) {
    return {
        _id: uuid.v4(),
        created: moment.now(),
        description: text,
        completed: false,
        state: 'PENDING'
    };
}

export const addTodoEntryAction = createAction(ActionConstants.ADD_TODO_ENTRY);
export const saveTodoEntryAction = createAction(ActionConstants.SAVE_TODO_ENTRY);
export const unsavedTodoEntryAction = createAction(ActionConstants.UNSAVED_TODO_ENTRY);

export const createTodoEntryAction = (text) => {
    return (dispatch) => {
        const entry = newEntry(text);

        dispatch(addTodoEntryAction(entry));
        return todoClient.create(entry)
            .then(() => {
                return dispatch(saveTodoEntryAction(entry._id));
            }).catch(() => {
                return dispatch(unsavedTodoEntryAction(entry._id));
            });
    };
};

export const closeTodoEntryAction = (id) => {
    return (dispatch, getState) => {
        dispatch({type: ActionConstants.CLOSE_TODO_ENTRY, payload: id});
        return todoClient.update(id, getState().todos[id]);
    };
};

export const reopenTodoEntryAction = (id) => {
    return (dispatch, getState) => {
        dispatch({type: ActionConstants.REOPEN_TODO_ENTRY, payload: id});
        return todoClient.update(id, getState().todos[id]);
    };
};

export const removeTodoEntryAction = (id) => {
    return (dispatch) => {
        return todoClient.delete(id)
            .then(() => {
                return dispatch({type: ActionConstants.REMOVE_TODO_ENTRY, payload: id});
            }).catch(() => {
                return dispatch({type: ActionConstants.REMOVE_TODO_ENTRY, payload: id});
            });
    };
};



