import React from 'react';
import Highlight from 'react-highlight';

/**
 * @class
 * @memberOf module:<%= appFileName %>
 * @classdesc DocComponent is a simple default page for the <%= appFileName %>.
 *            <%= appFileName %>nstrate use of context.router and {@link module:Reactator.ResponsiveComponent}
 */
export default class DocComponent extends React.PureComponent {
    constructor(props) {
        super(props);
        this.state = {
            modal: false
        };
    }

    render() {
        return (
            <div>
                <div className="card">
                    <div className="card-header primary-color-dark white-text">
                        Configuring Client App
                    </div>
                    <div className="card-block">
                    <Highlight className='language-javascript'>
                        {`
export default class <%= appFileName %>AppConfigurationBuilder extends ReactatorAppConfigurationBuillder {
    constructor() {
        super();

        this
            .withRoutes(new <%= appFileName %>Routes())
            .withStore((builder) => {
                builder
                    .withReducer(new TodoReducer())
                    .withReducer(new ApplicationReducer());

                if (typeof window !== 'undefined' && window.__PRELOADED_STATE__) {
                    builder.withInitialState(window.__PRELOADED_STATE__);
                }
            });
    }
}
`}
                        </Highlight>
                    </div>
                </div>
                <br />
                <div className="card">
                    <div className="card-header primary-color-dark white-text">
                        Starting Client App
                    </div>
                    <div className="card-block">
                    <Highlight className='language-javascript'>
                        {`
// <%= appFileName %> App Configuration
const configuration = new <%= appFileName %>AppConfigurationBuilder().build();

/**
 * @class
 * @classdesc <%= appFileName %>App is a simple single page app built using reactator.
 */
const app = new ReactatorClientApp(configuration);

//
// Start the Client App
//
app.start();
`}
                        </Highlight>
                    </div>
                </div>
                <br />
                <div className="card">
                    <div className="card-header primary-color-dark white-text">
                        Starting Server App
                    </div>
                    <div className="card-block">
                    <Highlight className='language-javascript'>
                        {`
//
// Express App
//
const app = express();
const port = 3000;

//
// Static assets
//
app.use(express.static(path.join(__dirname, '../../dist/<%= appFileName %>/'), {
    dotfiles: 'ignore',
    etag: false,
    extensions: ['htm', 'html'],
    index: false,
    maxAge: '1d',
    redirect: false,
    setHeaders: function(res) {
        res.set('x-timestamp', Date.now());
    }
}));

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: true}));

//
// TodoContainer
//
const todoContainer = new TodoContainer();

//
// Bind the container to the app
//
todoContainer.bind(app);

//
// Configure the app
//
const config = new <%= appFileName %>AppConfigurationBuilder()
    .withStore((storeBuilder) => {
        storeBuilder.withLoggerOptions({enabled: false});
    }).withActionFactory(new FilteredActionFactory(['LOAD_TODO'], () => {
        return todoContainer.getLoadActions();
    })).build();

//
// Start the app
//
new ReactatorServerApp(config)
    .start()
    .then((server) => {
        app.use(server.middleware({
            template: fs.readFileSync(path.join(__dirname, '../client/index.html.mustache'), 'utf8'),
            notFoundComponent: <NotFoundComponent />,
            internalServerErrorComponent: <InternalServerErrorComponent />
        }));

        app.listen(port);
    });
`}
                        </Highlight>
                    </div>
                </div>
            </div>
        );
    }
}
