import moment from 'moment';
import classNames from 'classnames';
import React, {PropTypes} from 'react';
import ReduxComponent from 'reactator/components/ReduxComponent';

function noop(e) {
    e.preventDefault();
}

export default ReduxComponent({
    entry: PropTypes.shape({
        _id: PropTypes.string.isRequired,
        created: PropTypes.number.isRequired,
        description: PropTypes.string.isRequired,
        completed: PropTypes.bool.isRequired
    }).isRequired,
    closeTodoEntry: PropTypes.func.isRequired,
    reopenTodoEntry: PropTypes.func.isRequired,
    removeTodoEntry: PropTypes.func.isRequired,
    showTodoEntryDetails: PropTypes.func.isRequired
}, (props) => {

    const action = props.entry.completed ?
        <button type="button" className="btn btn-primary btn-sm" onClick={() => props.reopenTodoEntry(props.entry._id)}><i className="fa fa-clock-o" aria-hidden="true"></i></button> :
        <button type="button" className="btn btn-success btn-sm" onClick={() => props.closeTodoEntry(props.entry._id)}><i className="fa fa-check" aria-hidden="true"></i></button>;

    return (
        <a href="#" onClick={noop} className="list-group-item list-group-item-action flex-column align-items-start">
            <div className="d-flex w-100 justify-content-between">
                <h3 className={classNames('mb-1', {'line-through': props.entry.completed})}>{props.entry.description}</h3>

                <div>
                    <small className="text-muted float-right">{moment(props.entry.created).calendar()}</small>
                    <br />
                    <button type="button" className="btn btn-danger btn-sm" onClick={() => props.removeTodoEntry(props.entry._id)}><i className="fa fa-times" aria-hidden="true"></i></button>
                    {action}
                    <button type="button" className="btn btn-outline-primary waves-effect btn-sm"
                        onClick={() => props.showTodoEntryDetails(props.entry._id)}><i className="fa fa-gear" aria-hidden="true"></i></button>
                </div>
            </div>
        </a>
    );
});
