import bodyParser from 'body-parser';
import express from 'express';
import fs from 'fs';
import path from 'path';
import React from 'react';
import ReactatorServerApp from 'reactator/ReactatorServerApp';
import {FilteredActionFactory} from 'reactator/actions/ActionFactory';
import <%= appFileName %>AppConfigurationBuilder from '../client/<%= appFileName %>AppConfigurationBuilder.js';
import InternalServerErrorComponent from '../client/components/InternalServerErrorComponent.js';
import NotFoundComponent from '../client/components/NotFoundComponent.js';
import TodoContainer from './TodoContainer.js';

//
// Express App
//
const app = express();
const port = 3000;

//
// Static assets
//
app.use(express.static(path.join(__dirname, '../../dist/<%= appFileName %>/'), {
    dotfiles: 'ignore',
    etag: false,
    extensions: ['htm', 'html'],
    index: false,
    maxAge: '1d',
    redirect: false,
    setHeaders: function(res) {
        res.set('x-timestamp', Date.now());
    }
}));

app.use(bodyParser.json());
app.use(bodyParser.urlencoded({extended: true}));

//
// TodoContainer
//
const todoContainer = new TodoContainer();

//
// Bind the container to the app
//
todoContainer.bind(app);

//
// Configure the app
//
const config = new <%= appFileName %>AppConfigurationBuilder()
    .withStore((storeBuilder) => {
        storeBuilder.withLoggerOptions({enabled: false});
    }).withActionFactory(new FilteredActionFactory(['LOAD_TODO'], () => {
        return todoContainer.getLoadActions();
    })).build();

//
// Start the app
//
new ReactatorServerApp(config)
    .start()
    .then((server) => {
        app.use(server.middleware({
            template: fs.readFileSync(path.join(__dirname, '../client/index.html.mustache'), 'utf8'),
            notFoundComponent: <NotFoundComponent />,
            internalServerErrorComponent: <InternalServerErrorComponent />
        }));

        app.listen(port);
    });
